@@ -138,10 +138,11 @@ load_file (BrowserConfig *config)
 
 			str = g_strdup_printf ("<b>%s</b>\n\n%s",
 					       _("Do you want to build the database dictionary?"),
-					       _("The database dictionary must be built before the database can be browsed, "
-						 "the process only takes a few minutes.\n\n"
-						 "It is saved and a re-building will only be necessary "
-						 "when the database structures changes."));
+					       _("The database dictionary must be built before the database can be browsed. "
+						 "The process only takes a few minutes.\n"
+						 "\n"
+						 "The dictionary will need to be rebuilt only if the database structure "
+                                                 "changes."));
 			
 			msg = gtk_message_dialog_new_with_markup (GTK_WINDOW (config->mainwin), 
 								  GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -468,8 +469,12 @@ function_get_args (GnomeDbServerFunction *func)
 			firstarg = FALSE;
 		else
 			g_string_append (string, ", ");
-		g_string_append (string,
-				 gnome_db_server_data_type_get_sqlname (GNOME_DB_SERVER_DATA_TYPE (args->data)));
+		if (args->data) 
+			g_string_append (string,
+					 gnome_db_server_data_type_get_sqlname (GNOME_DB_SERVER_DATA_TYPE (args->data)));
+		else
+			g_string_append (string, "*");
+				 
 		args = g_slist_next (args);
 	}
 	g_string_append (string, ")");
