@@ -52,8 +52,8 @@ struct _GnomeDbComboClass {
 
 GType         gnome_db_combo_get_type         (void);
 
-GtkWidget    *gnome_db_combo_new              (GnomeDbDict *dict);
-GtkWidget    *gnome_db_combo_new_with_model   (GnomeDbDict *dict, GdaDataModel *model, gint n_cols, gint *cols_index);
+GtkWidget    *gnome_db_combo_new              (void);
+GtkWidget    *gnome_db_combo_new_with_model   (GdaDataModel *model, gint n_cols, gint *cols_index);
 
 void          gnome_db_combo_set_model        (GnomeDbCombo *combo, GdaDataModel *model, gint n_cols, gint *cols_index);
 GdaDataModel *gnome_db_combo_get_model        (GnomeDbCombo *combo);
