@@ -1,6 +1,6 @@
 /* gnome-db-graphviz.c
  *
- * Copyright (C) 2003 Vivien Malerba
+ * Copyright (C) 2003 - 2005 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -148,9 +148,9 @@ gnome_db_graphviz_new (GnomeDbDict *dict)
 	GObject *obj;
 	GnomeDbGraphviz *gnome_db_graphviz;
 
-	g_return_val_if_fail (dict && IS_GNOME_DB_DICT (dict), NULL);
+	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 
-	obj = g_object_new (GNOME_DB_GRAPHVIZ_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_GRAPHVIZ_TYPE, "dict", ASSERT_DICT (dict), NULL);
 	gnome_db_graphviz = GNOME_DB_GRAPHVIZ (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_graphviz), 0);
 
