@@ -69,27 +69,12 @@ GtkWidget        *gnome_db_grid_new_with_select_query     (GnomeDbQuery *query,
 void              gnome_db_grid_set_sample_size           (GnomeDbGrid *grid, gint sample_size);
 void              gnome_db_grid_set_sample_start          (GnomeDbGrid *grid, gint sample_start);
 
+void              gnome_db_grid_get_selection_mode        (GnomeDbGrid *grid, GtkSelectionMode mode);
 GList            *gnome_db_grid_get_selection             (GnomeDbGrid *grid);
-void              gnome_db_grid_foreach_selected          (GnomeDbGrid *grid,
-							   GnomeDbGridForeachFunc foreach_func, gpointer user_data);
 void              gnome_db_grid_select_all                (GnomeDbGrid *grid);
 void              gnome_db_grid_unselect_all              (GnomeDbGrid *grid);
-
-void              gnome_db_grid_set_column_title          (GnomeDbGrid *grid, gint col, const gchar *title);
-const gchar      *gnome_db_grid_get_column_title          (GnomeDbGrid *grid, gint col);
-void              gnome_db_grid_set_title_icon_from_file  (GnomeDbGrid *grid, const gchar *file);
-void              gnome_db_grid_set_title_icon_from_stock (GnomeDbGrid *grid, const gchar *stock_id, GtkIconSize size);
-void              gnome_db_grid_set_show_title_icon       (GnomeDbGrid *grid, gboolean show);
-gboolean          gnome_db_grid_get_show_title_icon       (GnomeDbGrid *grid);
-
-/* FIXME: put into the GnomeDbDataWidget interface */
-void              gnome_db_grid_set_gda_model             (GnomeDbGrid *grid, GnomeDbDict *dict, GdaDataModel *model);
-GdaDataModel     *gnome_db_grid_get_gda_model             (GnomeDbGrid *grid);
-void              gnome_db_grid_set_model                 (GnomeDbGrid *grid, GnomeDbDataModel *model);
-
-void              gnome_db_grid_set_title                 (GnomeDbGrid *grid, const gchar *title);
-void              gnome_db_grid_set_show_title            (GnomeDbGrid *grid, gboolean show);
-
+void              gnome_db_grid_foreach_selected          (GnomeDbGrid *grid,
+							   GnomeDbGridForeachFunc foreach_func, gpointer user_data);
 G_END_DECLS
 
 #endif
