@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999-2002 The GNOME Foundation.
+ * Copyright (C) 1999 - 2005 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -29,7 +29,7 @@
 #include <libgnomedb/gnome-db-login-dialog.h>
 #include <libgnomedb/gnome-db-stock.h>
 #include <libgnomedb/gnome-db-util.h>
-#include "gnome-db-i18n.h"
+#include <glib/gi18n-lib.h>
 
 extern void gnome_db_stock_init (void);
 
@@ -93,6 +93,8 @@ static void
 gnome_db_login_dialog_init (GnomeDbLoginDialog *dialog, GnomeDbLoginDialogClass *klass)
 {
 	GtkWidget *hbox, *vbox, *image, *label;
+	GtkWidget *nb;
+	gchar *str;
 
 	g_return_if_fail (GNOME_DB_IS_LOGIN_DIALOG (dialog));
 
@@ -112,29 +114,40 @@ gnome_db_login_dialog_init (GnomeDbLoginDialog *dialog, GnomeDbLoginDialogClass
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 0);
 
-	/* image = gtk_image_new_from_stock (GNOME_DB_STOCK_DATABASE, GTK_ICON_SIZE_DIALOG); */
 	image = gtk_image_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db-database-login_48x48.png");
         gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
 	gtk_widget_show (image);
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
+	nb = gtk_notebook_new ();
+	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb), FALSE);
+	gtk_notebook_set_show_border (GTK_NOTEBOOK (nb), FALSE);
+	gtk_box_pack_start (GTK_BOX (hbox), nb, TRUE, TRUE, 0);
+	gtk_widget_show (nb);
+	g_object_set_data (G_OBJECT (dialog), "main_part", nb);	
+
 	vbox = gtk_vbox_new (FALSE, 12);
 	gtk_widget_show (vbox);
+	gtk_notebook_append_page (GTK_NOTEBOOK (nb), vbox, NULL);
+	gtk_widget_show (vbox);
 	
-	label = gnome_db_new_label_widget (_("Enter the arguments below to open a connection\n"
-					     "to a data source"));
+	str = g_strdup_printf ("<b>%s:</b>\n%s", _("Data source selection"),
+			       _("Enter the arguments below to open a connection\n"
+				 "to a data source"));
+	label = gtk_label_new ("");
+	gtk_label_set_markup (GTK_LABEL (label), str);
+	g_free (str);
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
         gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (label), FALSE);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
 	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
+	gtk_widget_show (label);
 
 	dialog->priv->login = gnome_db_login_new (NULL);
 	gnome_db_login_set_enable_create_button (GNOME_DB_LOGIN (dialog->priv->login), TRUE);
 	gtk_widget_show (dialog->priv->login);
 	gtk_box_pack_start (GTK_BOX (vbox), dialog->priv->login, TRUE, TRUE, 0);
-	
-	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 }
 
 static void
@@ -224,6 +237,11 @@ gnome_db_login_dialog_get_type (void)
 
 /**
  * gnome_db_login_dialog_new
+ * @title:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_login_dialog_new (const gchar *title)
@@ -245,6 +263,11 @@ gnome_db_login_dialog_new (const gchar *title)
 
 /**
  * gnome_db_login_dialog_run
+ * @dialog:
+ *
+ *
+ *
+ * Returns:
  */
 gboolean
 gnome_db_login_dialog_run (GnomeDbLoginDialog *dialog)
@@ -259,6 +282,11 @@ gnome_db_login_dialog_run (GnomeDbLoginDialog *dialog)
 
 /**
  * gnome_db_login_dialog_get_dsn
+ * @dialog:
+ *
+ *
+ *
+ * Returns:
  */
 const gchar *gnome_db_login_dialog_get_dsn (GnomeDbLoginDialog *dialog)
 {
@@ -268,6 +296,11 @@ const gchar *gnome_db_login_dialog_get_dsn (GnomeDbLoginDialog *dialog)
 
 /**
  * gnome_db_login_dialog_get_username
+ * @dialog:
+ *
+ *
+ *
+ * Returns:
  */
 const gchar *gnome_db_login_dialog_get_username (GnomeDbLoginDialog *dialog)
 {
@@ -277,6 +310,11 @@ const gchar *gnome_db_login_dialog_get_username (GnomeDbLoginDialog *dialog)
 
 /**
  * gnome_db_login_dialog_get_password
+ * @dialog:
+ *
+ *
+ *
+ * Returns:
  */
 const gchar *gnome_db_login_dialog_get_password (GnomeDbLoginDialog *dialog)
 {
