@@ -1,6 +1,6 @@
 /* gnome-db-query-parsing.c
  *
- * Copyright (C) 2003 - 2004 Vivien Malerba
+ * Copyright (C) 2003 - 2005 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,6 +24,8 @@
 #include "gnome-db-qf-field.h"
 #include "gnome-db-qf-value.h"
 #include "gnome-db-qf-all.h"
+#include "gnome-db-qf-func.h"
+#include "gnome-db-qf-agg.h"
 #include "gnome-db-ref-base.h"
 #include "gnome-db-target.h"
 #include "gnome-db-entity.h"
@@ -43,7 +45,6 @@
 #include "gnome-db-server-function.h"
 #include "gnome-db-server-aggregate.h"
 #include "gnome-db-data-handler.h"
-#include "gnome-db-qf-func.h"
 
 #include "gnome-db-query-private.h"
 #include "gnome-db-query-parsing.h"
@@ -1497,12 +1498,12 @@ parsed_create_func_query_field (GnomeDbQuery *query, gboolean add_to_query, Pars
 		gboolean new_field;
 
 		GnomeDbField *qfield = parsed_create_global_query_field (query, TRUE, pdata, 
-								    (sql_field *)dlist->data, 
-								    try_existing_field, &new_field, 
-								    NULL, error);
+									 (sql_field *)dlist->data, 
+									 try_existing_field, &new_field, 
+									 NULL, error);
 
 		if (!qfield) 
-			has_error = TRUE;
+			return NULL;
 		else {
 			args = g_slist_append (args, qfield);
 			arg_types = g_slist_append (arg_types, gnome_db_qfield_get_data_type (GNOME_DB_QFIELD (qfield)));
@@ -1523,37 +1524,58 @@ parsed_create_func_query_field (GnomeDbQuery *query, gboolean add_to_query, Pars
 	if (function || agg) {
 		if (function) {
 			/* actual object creation for GnomeDbServerFunction */
-			qfield = GNOME_DB_FIELD (gnome_db_qf_func_new_with_func (query, GNOME_DB_SERVER_FUNCTION (function)));
-			gnome_db_qf_func_set_args (GNOME_DB_QF_FUNC (qfield), args);
+			qfield = GNOME_DB_FIELD (gnome_db_qf_func_new_with_func (query, 
+										 GNOME_DB_SERVER_FUNCTION (function)));
+			has_error = ! gnome_db_qf_func_set_args (GNOME_DB_QF_FUNC (qfield), args);
+		}
+		else {
+			GnomeDbQfield *arg = NULL;
+			if (args && (g_slist_length (args) == 1))
+				arg = GNOME_DB_QFIELD (args->data);
+				
+			/* actual object creation for GnomeDbServerAggregate */
+			qfield = GNOME_DB_FIELD (gnome_db_qf_agg_new_with_agg (query, GNOME_DB_SERVER_AGGREGATE (agg)));
+			if (arg)
+				has_error = ! gnome_db_qf_agg_set_arg (GNOME_DB_QF_AGG (qfield), arg);
+			else
+				has_error = TRUE;
 		}
-		else
-			TO_IMPLEMENT;
 
 		gnome_db_base_set_name (GNOME_DB_BASE (qfield), funcname);
-
-		if (add_to_query) {
-			gnome_db_entity_add_field (GNOME_DB_ENTITY (query), qfield);
-			g_object_unref (G_OBJECT (qfield));
-		}
-	}
-	else
-		if (!has_error) {
-			GString *string = g_string_new ("");
-
-			g_string_append_printf (string, "%s (", funcname);
-			list = arg_types;
-			while (list) {
-				g_string_append (string, (list == arg_types) ? "" : ", ");
-				g_string_append_printf (string, "%s", gnome_db_base_get_name (GNOME_DB_BASE (list->data)));
-				list = g_slist_next (list);
-			}
-			g_string_append (string, ")");
+		
+		if (has_error) {
+			if (qfield)
+				g_object_unref (qfield);
+			qfield = NULL;
 			g_set_error (error,
 				     GNOME_DB_QUERY_ERROR,
 				     GNOME_DB_QUERY_SQL_ANALYSE_ERROR,
-				     _("Can't find function or aggregate '%s'"), string->str);
-			g_string_free (string, TRUE);
+				     _("Can't set aggregate or function's arguments"));
 		}
+		else {
+			if (add_to_query) {
+				gnome_db_entity_add_field (GNOME_DB_ENTITY (query), qfield);
+				g_object_unref (G_OBJECT (qfield));
+			}
+		}
+	}
+	else {
+		GString *string = g_string_new ("");
+		
+		g_string_append_printf (string, "%s (", funcname);
+		list = arg_types;
+		while (list) {
+			g_string_append (string, (list == arg_types) ? "" : ", ");
+			g_string_append_printf (string, "%s", gnome_db_base_get_name (GNOME_DB_BASE (list->data)));
+			list = g_slist_next (list);
+		}
+		g_string_append (string, ")");
+		g_set_error (error,
+			     GNOME_DB_QUERY_ERROR,
+			     GNOME_DB_QUERY_SQL_ANALYSE_ERROR,
+			     _("Can't find function or aggregate '%s'"), string->str);
+		g_string_free (string, TRUE);
+	}
 
 	/* memory de-allocation */
 	g_slist_free (args);
