@@ -207,9 +207,9 @@ gnome_db_ref_base_new (GnomeDbDict *dict)
 	GObject   *obj;
 	GnomeDbRefBase *gnome_db_ref_base;
 
-	g_return_val_if_fail (dict && IS_GNOME_DB_DICT (dict), NULL);
+	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 
-	obj = g_object_new (GNOME_DB_REF_BASE_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_REF_BASE_TYPE, "dict", ASSERT_DICT (dict), NULL);
 	gnome_db_ref_base = GNOME_DB_REF_BASE (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_ref_base), 0);
 
@@ -234,8 +234,8 @@ gnome_db_ref_base_new_no_ref_count (GnomeDbDict *dict)
 {
 	GObject *obj;
 
-	g_return_val_if_fail (dict && IS_GNOME_DB_DICT (dict), NULL);
-	obj = gnome_db_ref_base_new (dict);
+	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
+	obj = gnome_db_ref_base_new (ASSERT_DICT (dict));
 	GNOME_DB_REF_BASE (obj)->priv->increase_ref_object = FALSE;
 
 	return obj;
