@@ -536,8 +536,7 @@ gnome_db_data_cell_renderer_combo_start_editing (GtkCellRenderer     *cell,
 	if (cell_text->editable == FALSE)
 		return NULL;
 
-	combo = gnome_db_combo_new_with_model (gnome_db_base_get_dict (GNOME_DB_BASE (datacell->priv->data_model)),
-					       GDA_DATA_MODEL (datacell->priv->data_model),
+	combo = gnome_db_combo_new_with_model (GDA_DATA_MODEL (datacell->priv->data_model),
 					       datacell->priv->info->shown_n_cols, 
 					       datacell->priv->info->shown_cols_index);
 	
